@@ -8,20 +8,12 @@
 
 #undef ENABLE_RESOLVER
 
-#undef ENABLE_SMTP_SERVER
-
-#undef ENABLE_POP3
-
 #undef ENABLE_AUTH
 
-#undef ENABLE_MAILDIR
-
 #undef USE_LIB_CRYPTO
 
 #undef ENABLE_IDENT
 
-#undef ENABLE_MSERVER
-
 #undef CONF_DIR
 
 #undef DATA_DIR
