@@ -39,13 +39,13 @@ init_conf()
 		conf.mail_uid = passwd->pw_uid;
 	else {
 		fprintf(stderr, "user %s not found! (terminating)\n", DEF_MAIL_USER);
-		exit(EXIT_FAILURE);
+		exit(1);
 	}
 	if ((group = getgrnam(DEF_MAIL_GROUP)))
 		conf.mail_gid = group->gr_gid;
 	else {
 		fprintf(stderr, "group %s not found! (terminating)\n", DEF_MAIL_GROUP);
-		exit(EXIT_FAILURE);
+		exit(1);
 	}
 }
 
@@ -62,7 +62,7 @@ parse_boolean(gchar * rval)
 {
 	gchar **str;
 
-	DEBUG(6) fprintf(stderr, "parse_boolean: %s\n", rval);
+	DEBUG(9) fprintf(stderr, "parse_boolean: %s\n", rval);
 
 	str = true_strings;
 	while (*str) {
@@ -79,7 +79,7 @@ parse_boolean(gchar * rval)
 	}
 
 	fprintf(stderr, "cannot parse value '%s'\n", rval);
-	exit(EXIT_FAILURE);
+	exit(1);
 }
 
 /* make a list from each line in a file */
@@ -91,7 +91,7 @@ parse_list_file(gchar * fname)
 
 	if ((fptr = fopen(fname, "rt")) == NULL) {
 		logwrite(LOG_ALERT, "could not open %s for reading: %s\n", fname, strerror(errno));
-		exit(EXIT_FAILURE);
+		exit(1);
 	}
 
 	gchar buf[256];
@@ -100,7 +100,7 @@ parse_list_file(gchar * fname)
 		fgets(buf, 255, fptr);
 		if (buf[0] && (buf[0] != '#') && (buf[0] != '\n')) {
 			g_strchomp(buf);
-			DEBUG(6) fprintf(stderr,"parse_list_file: item = %s\n", buf);
+			DEBUG(9) fprintf(stderr,"parse_list_file: item = %s\n", buf);
 			list = g_list_append(list, g_strdup(buf));
 		}
 	}
@@ -117,7 +117,7 @@ parse_list(gchar * line, gboolean read_file)
 	gchar buf[256];
 	gchar *p, *q;
 
-	DEBUG(6) fprintf(stderr, "parsing list %s, file?:%d\n", line, read_file);
+	DEBUG(9) fprintf(stderr, "parsing list %s, file?:%d\n", line, read_file);
 
 	p = line;
 	while (*p != '\0') {
@@ -134,7 +134,7 @@ parse_list(gchar * line, gboolean read_file)
 			/* just a normal item */
 			list = g_list_append(list, g_strdup(buf));
 
-		DEBUG(6) fprintf(stderr, "item = %s\n", buf);
+		DEBUG(9) fprintf(stderr, "item = %s\n", buf);
 
 		if (*p)
 			p++;
@@ -142,8 +142,14 @@ parse_list(gchar * line, gboolean read_file)
 	return list;
 }
 
+/* Split the addrs at '@' into local_part and domain. Without an '@'
+   everything is local_part. Create address structs, which are put
+   into a list and returned.
+   This funktion is used for lists of addrs containing globbing chars (* and ?).
+   We don't need valid RFC821 addresses here, just patterns to match against.
+*/
 static GList*
-parse_address_list(gchar * line, gboolean read_file)
+parse_address_glob_list(gchar * line, gboolean read_file)
 {
 	GList *plain_list = parse_list(line, read_file);
 	GList *node;
@@ -151,13 +157,33 @@ parse_address_list(gchar * line, gboolean read_file)
 
 	foreach(plain_list, node) {
 		gchar *item = (gchar *) (node->data);
-		address *addr = create_address(item, TRUE);
-		if (addr)
-			list = g_list_append(list, addr);
+		char* at;
+		char* p;
+		address *addr = calloc(1, sizeof(address));
+
+		for (p=item+strlen(item)-1; isspace(*p) || *p=='>'; p--) {
+			*p = '\0';
+		}
+		for (p=item; isspace(*p) || *p=='<'; p++) {
+		}
+
+		addr->address = strdup(p);
+		at = strrchr(p, '@');
+		if (at) {
+			*at = '\0';
+			addr->local_part = strdup(p);
+			addr->domain = strdup(at+1);
+		} else {
+			addr->local_part = strdup(p);
+			/* No `@', thus any domain is okay. */
+			addr->domain = "*";
+		}
+		list = g_list_append(list, addr);
+		DEBUG(6) debugf("parse_address_glob_list: read pattern `%s' `%s'\n",
+		                addr->local_part, addr->domain);
 		g_free(item);
 	}
 	g_list_free(plain_list);
-
 	return list;
 }
 
@@ -185,7 +211,7 @@ parse_resolve_list(gchar * line)
 #endif
 		} else {
 			logwrite(LOG_ALERT, "unknown resolver %s\n", item);
-			exit(EXIT_FAILURE);
+			exit(1);
 		}
 		g_free(item);
 	}
@@ -200,7 +226,7 @@ parse_interface(gchar * line, gint def_port)
 	gchar *p, *q;
 	interface *iface;
 
-	DEBUG(6) fprintf(stderr, "parse_interface: %s\n", line);
+	DEBUG(9) fprintf(stderr, "parse_interface: %s\n", line);
 
 	p = line;
 	q = buf;
@@ -216,7 +242,7 @@ parse_interface(gchar * line, gint def_port)
 		iface->port = atoi(p);
 	} else
 		iface->port = def_port;
-	DEBUG(6) fprintf(stderr,"rval=%s, address:port=%s:%i\n",line, iface->address, iface->port);
+	DEBUG(9) fprintf(stderr,"rval=%s, address:port=%s:%i\n",line, iface->address, iface->port);
 
 	return iface;
 }
@@ -230,7 +256,7 @@ parse_network(gchar * line, gint def_port)
 	struct in_addr addr, mask_addr, net_addr, *p_net_addr;
 	guint n;
 
-	DEBUG(6) fprintf(stderr, "parse_network: %s\n", line);
+	DEBUG(9) fprintf(stderr, "parse_network: %s\n", line);
 
 	p = line;
 	q = buf;
@@ -240,7 +266,7 @@ parse_network(gchar * line, gint def_port)
 
 	if ((addr.s_addr = inet_addr(buf)) == INADDR_NONE) {
 		fprintf(stderr, "'%s' is not a valid address (must be ip)\n", buf);
-		exit(EXIT_FAILURE);
+		exit(1);
 	}
 
 	if (*p) {
@@ -251,7 +277,7 @@ parse_network(gchar * line, gint def_port)
 			n = i ? ~((1 << (32 - i)) - 1) : 0;
 		else {
 			fprintf(stderr, "'%d' is not a valid net mask (must be >= 0 and <= 32)\n", i);
-			exit(EXIT_FAILURE);
+			exit(1);
 		}
 	} else
 		n = 0;
@@ -315,13 +341,13 @@ read_lval(FILE * in, gchar * buf, gint size)
 	gint c;
 	gchar *ptr = buf;
 
-	DEBUG(6) fprintf(stderr, "read_lval()\n");
+	DEBUG(9) fprintf(stderr, "read_lval()\n");
 
 	if (!eat_spaces(in))
 		return FALSE;
 
 	c = fgetc(in);
-	DEBUG(6) fprintf(stderr, "read_lval() 2\n");
+	DEBUG(9) fprintf(stderr, "read_lval() 2\n");
 	while ((isalnum(c) || c == '_' || c == '-' || c == '.')
 	       && (ptr < buf + size - 1)
 	       && (c != EOF)) {
@@ -341,7 +367,7 @@ read_lval(FILE * in, gchar * buf, gint size)
 
 	eat_spaces(in);
 
-	DEBUG(6) fprintf(stderr, "lval = %s\n", buf);
+	DEBUG(9) fprintf(stderr, "lval = %s\n", buf);
 
 	return buf[0] != '\0';
 }
@@ -352,7 +378,7 @@ read_rval(FILE * in, gchar * buf, gint size)
 	gint c;
 	gchar *ptr = buf;
 
-	DEBUG(6) fprintf(stderr, "read_rval()\n");
+	DEBUG(9) fprintf(stderr, "read_rval()\n");
 
 	if (!eat_spaces(in))
 		return FALSE;
@@ -389,7 +415,7 @@ read_rval(FILE * in, gchar * buf, gint size)
 
 	eat_line_trailing(in);
 
-	DEBUG(6) fprintf(stderr, "rval = %s\n", buf);
+	DEBUG(9) fprintf(stderr, "rval = %s\n", buf);
 
 	return TRUE;
 }
@@ -399,7 +425,7 @@ read_statement(FILE * in, gchar * lval, gint lsize, gchar * rval, gint rsize)
 {
 	gint c;
 
-	DEBUG(6) fprintf(stderr, "read_statement()\n");
+	DEBUG(9) fprintf(stderr, "read_statement()\n");
 
 	/* eat comments and empty lines: */
 	if (!eat_comments(in))
@@ -409,14 +435,14 @@ read_statement(FILE * in, gchar * lval, gint lsize, gchar * rval, gint rsize)
 		return FALSE;
 	}
 
-	DEBUG(6) fprintf(stderr, "  lval = %s\n", lval);
+	DEBUG(9) fprintf(stderr, "  lval = %s\n", lval);
 	if ((c = fgetc(in) == '=')) {
 		if (read_rval(in, rval, rsize)) {
-			DEBUG(6) fprintf(stderr, "  rval = %s\n", rval);
+			DEBUG(9) fprintf(stderr, "  rval = %s\n", rval);
 			return TRUE;
 		}
 	} else {
-		DEBUG(6) fprintf(stderr,"  '=' expected after %s, char was '%c'\n", lval, c);
+		DEBUG(9) fprintf(stderr,"  '=' expected after %s, char was '%c'\n", lval, c);
 		fprintf(stderr, "'=' expected after %s, char was '%c'\n", lval, c);
 	}
 	return FALSE;
@@ -428,20 +454,22 @@ read_conf(gchar * filename)
 	FILE *in;
 
 	conf.log_max_pri = 7;
-	conf.remote_port = 25;
 	conf.do_relay = TRUE;
-	conf.alias_local_cmp = strcmp;
+	conf.localpartcmp = strcmp;
 	conf.max_defer_time = 86400 * 4;  /* 4 days */
 	conf.max_msg_size = 0; /* no limit on msg size */
+	conf.spool_dir = SPOOL_DIR;
+	conf.mail_dir = "/var/mail";
+	conf.listen_addresses = g_list_append(NULL, parse_interface("localhost", 25));
 
 	if ((in = fopen(filename, "r")) == NULL) {
-		fprintf(stderr, "could not open config file %s: %s\n", filename, strerror(errno));
+		logwrite(LOG_ALERT, "could not open config file %s: %s\n", filename, strerror(errno));
 		return FALSE;
 	}
 
 	gchar lval[256], rval[2048];
 	while (read_statement(in, lval, 256, rval, 2048)) {
-		DEBUG(6) fprintf(stderr,"read_conf(): lval=%s\n", lval);
+		DEBUG(9) fprintf(stderr,"read_conf(): lval=%s\n", lval);
 		if (strcmp(lval, "debug_level") == 0)
 			conf.debug_level = atoi(rval);
 		else if (strcmp(lval, "run_as_user") == 0) {
@@ -463,8 +491,8 @@ read_conf(gchar * filename)
 			else {
 				char buf[256];
 				FILE *fptr = fopen(rval, "rt");
-				if (fptr) {
-					fprintf(stderr, "could not open %s: %s\n", rval, strerror(errno));
+				if (!fptr) {
+					logwrite(LOG_ALERT, "could not open %s: %s\n", rval, strerror(errno));
 					return FALSE;
 				}
 				fgets(buf, 255, fptr);
@@ -472,10 +500,6 @@ read_conf(gchar * filename)
 				conf.host_name = g_strdup(buf);
 				fclose(fptr);
 			}
-		} else if (strcmp(lval, "remote_port") == 0) {
-			fprintf(stderr, "the remote_port option is now deprecated. Use 'mail_host' in the\n"
-							"route configuration instead. See man masqmail.route\n");
-			conf.remote_port = atoi(rval);
 		} else if (strcmp(lval, "local_hosts") == 0)
 			conf.local_hosts = parse_list(rval, FALSE);
 		else if (strcmp(lval, "local_addresses") == 0)
@@ -492,16 +516,14 @@ read_conf(gchar * filename)
 			conf.do_relay = parse_boolean(rval);
 		else if (strcmp(lval, "alias_file") == 0) {
 			conf.alias_file = g_strdup(rval);
-		} else if (strcmp(lval, "alias_local_caseless") == 0) {
-			conf.alias_local_cmp = parse_boolean(rval) ? strcasecmp : strcmp;
+		} else if (strcmp(lval, "caseless_matching") == 0) {
+			conf.localpartcmp = parse_boolean(rval) ? strcasecmp : strcmp;
 		} else if (strcmp(lval, "mbox_default") == 0) {
 			conf.mbox_default = g_strdup(rval);
 		} else if (strcmp(lval, "mbox_users") == 0) {
 			conf.mbox_users = parse_list(rval, TRUE);
 		} else if (strcmp(lval, "mda_users") == 0) {
 			conf.mda_users = parse_list(rval, TRUE);
-		} else if (strcmp(lval, "maildir_users") == 0) {
-			conf.maildir_users = parse_list(rval, TRUE);
 		} else if (strcmp(lval, "mda") == 0) {
 			conf.mda = g_strdup(rval);
 		} else if (strcmp(lval, "mda_fromline") == 0) {
@@ -534,7 +556,7 @@ read_conf(gchar * filename)
 			}
 			g_list_free(tmp_list);
 #else
-			fprintf(stderr, "%s ignored: not compiled with ident support\n", lval);
+			logwrite(LOG_WARNING, "%s ignored: not compiled with ident support\n", lval);
 #endif
 		} else if ((strncmp(lval, "connect_route.", 14) == 0)
 		           || (strncmp(lval, "online_routes.", 14) == 0)) {
@@ -543,56 +565,39 @@ read_conf(gchar * filename)
 			conf.connect_routes = g_list_append(conf.connect_routes, pair);
 		} else if (strcmp(lval, "local_net_route") == 0) {
 			conf.local_net_routes = parse_list(rval, FALSE);
-		} else if (strcmp(lval, "online_detect") == 0)
-			conf.online_detect = g_strdup(rval);
-		else if (strcmp(lval, "online_file") == 0)
-			conf.online_file = g_strdup(rval);
-		else if (strcmp(lval, "online_pipe") == 0)
-			conf.online_pipe = g_strdup(rval);
-		else if (strcmp(lval, "mserver_iface") == 0)
-			conf.mserver_iface = parse_interface(rval, 224);
+		} else if (strcmp(lval, "online_query") == 0)
+			conf.online_query = g_strdup(rval);
 		else if (strcmp(lval, "do_queue") == 0)
 			conf.do_queue = parse_boolean(rval);
-		else if (strncmp(lval, "get.", 4) == 0) {
-#ifdef ENABLE_POP3
-			table_pair *pair = create_pair_string(&(lval[4]), rval);
-			conf.get_names = g_list_append(conf.get_names, pair);
-#else
-			fprintf(stderr, "get.<name> ignored: not compiled with pop support\n");
-#endif
-		} else if (strncmp(lval, "online_gets.", 12) == 0) {
-#ifdef ENABLE_POP3
-			GList *file_list = parse_list(rval, FALSE);
-			table_pair *pair = create_pair(&(lval[12]), file_list);
-			conf.online_gets = g_list_append(conf.online_gets, pair);
-#else
-			fprintf(stderr, "online_gets.<name> ignored: not compiled with pop support\n");
-#endif
-		} else if (strcmp(lval, "errmsg_file") == 0)
+		else if (strcmp(lval, "errmsg_file") == 0)
 			conf.errmsg_file = g_strdup(rval);
 		else if (strcmp(lval, "warnmsg_file") == 0)
 			conf.warnmsg_file = g_strdup(rval);
 		else if (strcmp(lval, "warn_intervals") == 0)
 			conf.warn_intervals = parse_list(rval, FALSE);
 		else if (strcmp(lval, "max_defer_time") == 0) {
-			gint dummy;
-			gint ival = time_interval(rval, &dummy);
+			gint ival = time_interval(rval);
 			if (ival < 0)
-				fprintf(stderr, "invalid time interval for 'max_defer_time': %s\n", rval);
+				logwrite(LOG_WARNING, "invalid time interval for 'max_defer_time': %s\n", rval);
 			else
 				conf.max_defer_time = ival;
 		} else if (strcmp(lval, "log_user") == 0)
 			conf.log_user = g_strdup(rval);
 		else if(strcmp(lval, "max_msg_size") == 0) {
 			conf.max_msg_size = atol(rval);
-			DEBUG(6) fprintf(stderr,"rval=%s, conf.max_msg_size=%ld\n",
+			DEBUG(9) fprintf(stderr,"rval=%s, conf.max_msg_size=%ld\n",
 			                 rval, conf.max_msg_size);
 		}
 		else
-			fprintf(stderr, "var '%s' not (yet) known, ignored\n", lval);
+			logwrite(LOG_WARNING, "var '%s' not (yet) known, ignored\n", lval);
 	}
 	fclose(in);
 
+	if (!conf.host_name) {
+		logwrite(LOG_ALERT, "`host_name' MUST be set in masqmail.conf. See man page\n");
+		return FALSE;
+	}
+
 	if (conf.errmsg_file == NULL)
 		conf.errmsg_file = g_strdup(DATA_DIR "/tpl/failmsg.tpl");
 	if (conf.warnmsg_file == NULL)
@@ -607,6 +612,20 @@ read_conf(gchar * filename)
 	if (conf.warn_intervals == NULL)
 		conf.warn_intervals = parse_list("1h;4h;8h;1d;2d;3d", FALSE);
 
+	if (!conf.local_hosts) {
+		char* shortname = strdup(conf.host_name);
+		char* p = strchr(shortname, '.');
+		if (p) {
+			*p = '\0';
+		}
+		/* we don't care if shortname and conf.host_name are the same */
+		char* local_hosts_str = g_strdup_printf("localhost;%s;%s", shortname, conf.host_name);
+		conf.local_hosts = parse_list(local_hosts_str, FALSE);
+		free(shortname);
+		free(local_hosts_str);
+	}
+
+
 	return TRUE;
 }
 
@@ -624,7 +643,6 @@ read_route(gchar * filename, gboolean is_local_net)
 	route->filename = g_strdup(filename);
 	route->name = g_strdup(filename);  /* quick hack */
 
-	route->protocol = g_strdup("smtp");
 	route->expand_h_sender_address = TRUE;
 
 	route->is_local_net = is_local_net;
@@ -639,10 +657,8 @@ read_route(gchar * filename, gboolean is_local_net)
 
 	gchar lval[256], rval[2048];
 	while (read_statement(in, lval, 256, rval, 2048)) {
-		if (strcmp(lval, "protocol") == 0)
-			route->protocol = g_strdup(rval);
-		else if (strcmp(lval, "mail_host") == 0)
-			route->mail_host = parse_interface(rval, conf.remote_port);
+		if (strcmp(lval, "mail_host") == 0)
+			route->mail_host = parse_interface(rval, 25);
 		else if (strcmp(lval, "helo_name") == 0)
 			route->helo_name = g_strdup(rval);
 		else if (strcmp(lval, "wrapper") == 0)
@@ -655,18 +671,16 @@ read_route(gchar * filename, gboolean is_local_net)
 			route->instant_helo = parse_boolean(rval);
 		else if (strcmp(lval, "do_pipelining") == 0)
 			route->do_pipelining = parse_boolean(rval);
-		else if (strcmp(lval, "allowed_return_paths") == 0)
-			route->allowed_return_paths = parse_address_list(rval, TRUE);
-		else if (strcmp(lval, "allowed_mail_locals") == 0)
-			route->allowed_mail_locals = parse_list(rval, TRUE);
-		else if (strcmp(lval, "not_allowed_return_paths") == 0)
-			route->not_allowed_return_paths = parse_address_list(rval, TRUE);
-		else if (strcmp(lval, "not_allowed_mail_locals") == 0)
-			route->not_allowed_mail_locals = parse_list(rval, TRUE);
-		else if (strcmp(lval, "allowed_rcpt_domains") == 0)
-			route->allowed_rcpt_domains = parse_list(rval, TRUE);
-		else if (strcmp(lval, "not_allowed_rcpt_domains") == 0)
-			route->not_allowed_rcpt_domains = parse_list(rval, TRUE);
+
+		else if (strcmp(lval, "allowed_senders") == 0)
+			route->allowed_senders = parse_address_glob_list(rval, TRUE);
+		else if (strcmp(lval, "denied_senders") == 0)
+			route->denied_senders = parse_address_glob_list(rval, TRUE);
+		else if (strcmp(lval, "allowed_recipients") == 0)
+			route->allowed_recipients = parse_address_glob_list(rval, TRUE);
+		else if (strcmp(lval, "denied_recipients") == 0)
+			route->denied_recipients = parse_address_glob_list(rval, TRUE);
+
 		else if (strcmp(lval, "set_h_from_domain") == 0)
 			route->set_h_from_domain = g_strdup(rval);
 		else if (strcmp(lval, "set_h_reply_to_domain") == 0)
@@ -745,13 +759,7 @@ read_route(gchar * filename, gboolean is_local_net)
 			logwrite(LOG_WARNING, "%s ignored: not compiled with auth support.\n", lval);
 		}
 #endif
-		else if (strcmp(lval, "pop3_login") == 0) {
-#ifdef ENABLE_POP3
-			route->pop3_login = g_strdup(rval);
-#else
-			logwrite(LOG_WARNING, "pop3_login ignored: not compiled with pop support.\n");
-#endif
-		} else if (strcmp(lval, "pipe") == 0) {
+		else if (strcmp(lval, "pipe") == 0) {
 			route->pipe = g_strdup(rval);
 		} else if (strcmp(lval, "pipe_fromline") == 0) {
 			route->pipe_fromline = parse_boolean(rval);
@@ -763,16 +771,14 @@ read_route(gchar * filename, gboolean is_local_net)
 			logwrite(LOG_WARNING, "var '%s' not (yet) known, ignored\n", lval);
 	}
 
-	if (route->resolve_list == NULL) {
-		if (is_local_net) {
-			route->resolve_list = g_list_append(NULL, resolve_byname);
-		} else {
+	if (!route->resolve_list) {
 #ifdef ENABLE_RESOLVER
+		if (!is_local_net) {
 			route->resolve_list = g_list_append(route->resolve_list, resolve_dns_mx);
 			route->resolve_list = g_list_append(route->resolve_list, resolve_dns_a);
-#endif
-			route->resolve_list = g_list_append(route->resolve_list, resolve_byname);
 		}
+#endif
+		route->resolve_list = g_list_append(route->resolve_list, resolve_byname);
 	}
 	fclose(in);
 	ok = TRUE;
@@ -813,8 +819,6 @@ destroy_route(connect_route * r)
 {
 	if (r->filename)
 		g_free(r->filename);
-	if (r->protocol)
-		g_free(r->protocol);
 	if (r->mail_host) {
 		g_free(r->mail_host->address);
 		g_free(r->mail_host);
@@ -823,10 +827,10 @@ destroy_route(connect_route * r)
 		g_free(r->wrapper);
 	if (r->helo_name)
 		g_free(r->helo_name);
-	_g_list_free_all(r->allowed_mail_locals);
-	_g_list_free_all(r->not_allowed_mail_locals);
-	_g_list_free_all(r->allowed_rcpt_domains);
-	_g_list_free_all(r->not_allowed_rcpt_domains);
+	_g_list_free_all(r->allowed_senders);
+	_g_list_free_all(r->denied_senders);
+	_g_list_free_all(r->allowed_recipients);
+	_g_list_free_all(r->denied_recipients);
 	if (r->set_h_from_domain)
 		g_free(r->set_h_from_domain);
 	if (r->set_h_reply_to_domain)
@@ -844,10 +848,6 @@ destroy_route(connect_route * r)
 		g_free(r->auth_login);
 	if (r->auth_secret)
 		g_free(r->auth_secret);
-#endif
-#ifdef ENABLE_POP3
-	if (r->pop3_login)
-		g_free(r->pop3_login);
 #endif
 	if (r->pipe)
 		g_free(r->pipe);
@@ -894,100 +894,6 @@ destroy_route_list(GList * list)
 	g_list_free(list);
 }
 
-#ifdef ENABLE_POP3
-
-get_conf*
-read_get_conf(gchar * filename)
-{
-	FILE *in;
-
-	get_conf *gc = g_malloc(sizeof(get_conf));
-	memset(gc, 0, sizeof(get_conf));
-
-	gc->server_port = 110;
-
-	if ((in = fopen(filename, "r")) == NULL) {
-		logwrite(LOG_ALERT, "could not open get file %s: %s\n", filename, strerror(errno));
-		g_free(gc);
-		return NULL;
-	}
-
-	gchar lval[256], rval[2048];
-	while (read_statement(in, lval, 256, rval, 2048)) {
-		if (strcmp(lval, "protocol") == 0)
-			gc->protocol = g_strdup(rval);
-		else if (strcmp(lval, "server") == 0)
-			gc->server_name = g_strdup(rval);
-		else if (strcmp(lval, "port") == 0)
-			gc->server_port = atoi(rval);
-		else if (strcmp(lval, "wrapper") == 0)
-			gc->wrapper = g_strdup(rval);
-		else if (strcmp(lval, "user") == 0)
-			gc->login_user = g_strdup(rval);
-		else if (strcmp(lval, "pass") == 0)
-			gc->login_pass = g_strdup(rval);
-		else if (strcmp(lval, "address") == 0)
-			gc->address = create_address_qualified(rval, TRUE, conf.host_name);
-		else if (strcmp(lval, "return_path") == 0)
-			gc->return_path = create_address_qualified(rval, TRUE, conf.host_name);
-		else if (strcmp(lval, "do_ssl") == 0)
-			/* we ignore this. This option is used by sqilconf */
-			;
-		else if (strcmp(lval, "do_keep") == 0)
-			gc->do_keep = parse_boolean(rval);
-		else if (strcmp(lval, "do_uidl") == 0)
-			gc->do_uidl = parse_boolean(rval);
-		else if (strcmp(lval, "do_uidl_dele") == 0)
-			gc->do_uidl_dele = parse_boolean(rval);
-		else if (strcmp(lval, "max_size") == 0)
-			gc->max_size = atoi(rval);
-		else if (strcmp(lval, "max_size_delete") == 0)
-			gc->max_size_delete = parse_boolean(rval);
-		else if (strcmp(lval, "max_count") == 0)
-			gc->max_count = atoi(rval);
-		else if (strcmp(lval, "resolve_list") == 0)
-			gc->resolve_list = parse_resolve_list(rval);
-		else
-			logwrite(LOG_WARNING, "var '%s' not (yet) known, ignored\n", lval);
-	}
-	fclose(in);
-
-	if (gc->resolve_list == NULL) {
-#ifdef ENABLE_RESOLVER
-		gc->resolve_list = g_list_append(NULL, resolve_dns_a);
-#endif
-		gc->resolve_list = g_list_append(NULL, resolve_byname);
-	}
-
-	if (gc->protocol == NULL)
-		gc->protocol = g_strdup("pop3");
-	return gc;
-}
-
-void
-destroy_get_conf(get_conf * gc)
-{
-	if (gc->protocol)
-		g_free(gc->protocol);
-	if (gc->server_name)
-		g_free(gc->server_name);
-	if (gc->login_user)
-		g_free(gc->login_user);
-	if (gc->login_pass)
-		g_free(gc->login_pass);
-	if (gc->wrapper)
-		g_free(gc->wrapper);
-	if (gc->address)
-		destroy_address(gc->address);
-	if (gc->return_path)
-		destroy_address(gc->return_path);
-	if (gc->resolve_list)
-		g_list_free(gc->resolve_list);
-	g_free(gc);
-}
-
-#endif
-
 connect_route*
 create_local_route()
 {
@@ -998,9 +904,8 @@ create_local_route()
 		return NULL;
 	}
 	memset(route, 0, sizeof(connect_route));
-	route->protocol = g_strdup("smtp");
 	route->is_local_net = TRUE;
-	route->name = g_strdup("local_net (default)");
+	route->name = g_strdup("default local_net_route");
 	route->expand_h_sender_address = TRUE;
 	route->resolve_list = g_list_append(NULL, resolve_byname);
 	route->connect_error_fail = TRUE;
