@@ -1,5 +1,6 @@
 /*  MasqMail
     Copyright (C) 1999-2001 Oliver Kurth
+    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -189,71 +190,82 @@ rewrite_headers(msg_out * msgout, connect_route * route)
 	DEBUG(5) debugf("rewrite_headers() returning\n");
 }
 
+/*
+Split a recipient list into the three groups:
+- local recipients
+- local net recipients
+- other/remote/online recipients
+It should be possible to call the function like:
+	split_rcpts(rcpts, hostlist, local, others, others);
+This would split online between local and localnet+online recipients.
+(untested yet; remove this line if you saw it worked -- meillo 2010-10-21)
+If host_list is NULL, only splitting between local and other is done.
+*/
 void
-rcptlist_with_one_of_hostlist(GList * rcpt_list, GList * host_list, GList ** p_rcpt_list, GList ** p_non_rcpt_list)
+split_rcpts(GList* rcpt_list, GList* localnets, GList** rl_local, GList** rl_localnet, GList** rl_others)
 {
 	GList *rcpt_node;
+	GList *host_node = NULL;
+	address *rcpt = NULL;
 
 	if (rcpt_list == NULL)
 		return;
 
 	foreach(rcpt_list, rcpt_node) {
-		address *rcpt = (address *) (rcpt_node->data);
-		GList *host_node = NULL;
+		rcpt = (address *) (rcpt_node->data);
+		host_node = NULL;
 
-		foreach(host_list, host_node) {
-			gchar *host = (gchar *) (host_node->data);
-			if (fnmatch(host, rcpt->domain, FNM_CASEFOLD) == 0)
-				break;
-		}
-		if (host_node) {
-			if (p_rcpt_list)
-				*p_rcpt_list = g_list_append(*p_rcpt_list, rcpt);
-		} else {
-			if (p_non_rcpt_list)
-				*p_non_rcpt_list = g_list_append(*p_non_rcpt_list, rcpt);
-		}
-
-	}
-}
-
-void
-rcptlist_with_addr_is_local(GList * rcpt_list, GList ** p_rcpt_list, GList ** p_non_rcpt_list)
-{
-	GList *rcpt_node;
-
-	if (rcpt_list == NULL)
-		return;
-
-	foreach(rcpt_list, rcpt_node) {
-		address *rcpt = (address *) (rcpt_node->data);
 		if (addr_is_local(rcpt)) {
-			if (p_rcpt_list)
-				*p_rcpt_list = g_list_append(*p_rcpt_list, rcpt);
+			if (rl_local)
+				*rl_local = g_list_append(*rl_local, rcpt);
 		} else {
-			if (p_non_rcpt_list)
-				*p_non_rcpt_list = g_list_append(*p_non_rcpt_list, rcpt);
+			/* if localnets is NULL, host_node will be NULL,
+			   hence all non-locals are put to others */
+			foreach(localnets, host_node) {
+				gchar *host = (gchar *) (host_node->data);
+				if (fnmatch(host, rcpt->domain, FNM_CASEFOLD) == 0)
+					break;
+			}
+			if (host_node) {
+				if (rl_localnet)
+					*rl_localnet = g_list_append(*rl_localnet, rcpt);
+			} else {
+				if (rl_others)
+					*rl_others = g_list_append(*rl_others, rcpt);
+			}
 		}
-
 	}
 }
 
 static gint
-_g_list_addrcmp(gconstpointer a, gconstpointer b)
+_g_list_addrcmp(gconstpointer pattern, gconstpointer addr)
 {
-	return addr_match((address *) a, (address *) b);
+	int res;
+	address* patternaddr = (address*) pattern;
+	address* stringaddr = (address*) addr;
+
+	DEBUG(6) debugf("_g_list_addrcmp: pattern `%s' `%s' on string `%s' `%s'\n",
+	                patternaddr->local_part, patternaddr->domain,
+	                stringaddr->local_part, stringaddr->domain);
+	/* TODO: check if we should match here dependent on caseless_matching */
+	res = fnmatch(patternaddr->local_part, stringaddr->local_part, 0);
+	if (res != 0) {
+		DEBUG(6) debugf("_g_list_addrcmp: ... failed on local_part\n");
+		return res;
+	}
+	res = fnmatch(patternaddr->domain, stringaddr->domain, FNM_CASEFOLD);
+	DEBUG(6) debugf("_g_list_addrcmp: ... %s\n", (res==0) ? "matched" : "failed on domain");
+	return res;
 }
 
 gboolean
-route_is_allowed_return_path(connect_route * route, address * ret_path)
+route_sender_is_allowed(connect_route * route, address * ret_path)
 {
-	if (route->not_allowed_return_paths != NULL) {
-		if (g_list_find_custom(route->not_allowed_return_paths, ret_path, _g_list_addrcmp) != NULL) {
-			return FALSE;
-		}
+	if (route->denied_senders && g_list_find_custom(route->denied_senders, ret_path, _g_list_addrcmp)) {
+		return FALSE;
 	}
-	if (route->allowed_return_paths != NULL) {
-		if (g_list_find_custom(route->allowed_return_paths, ret_path, _g_list_addrcmp) != NULL) {
+	if (route->allowed_senders) {
+		if (g_list_find_custom(route->allowed_senders, ret_path, _g_list_addrcmp)) {
 			return TRUE;
 		} else {
 			return FALSE;
@@ -262,49 +274,25 @@ route_is_allowed_return_path(connect_route * route, address * ret_path)
 	return TRUE;
 }
 
-static gint
-_g_list_strcmp(gconstpointer a, gconstpointer b)
-{
-	return (gint) strcmp(a, b);
-}
-
-gboolean
-route_is_allowed_mail_local(connect_route * route, address * ret_path)
-{
-	gchar *loc_part = ret_path->local_part;
-
-	if (route->not_allowed_mail_locals != NULL) {
-		if (g_list_find_custom(route->not_allowed_mail_locals, loc_part, _g_list_strcmp) != NULL)
-			return FALSE;
-	}
-	if (route->allowed_mail_locals != NULL) {
-		if (g_list_find_custom(route->allowed_mail_locals, loc_part, _g_list_strcmp) != NULL)
-			return TRUE;
-		else
-			return FALSE;
-	}
-	return TRUE;
-}
-
 /*
    Make lists of matching/not matching rcpts.
    Local domains are NOT regared here, these should be sorted out previously
 */
 void
-msg_rcptlist_route(connect_route * route, GList * rcpt_list, GList ** p_rcpt_list, GList ** p_non_rcpt_list)
+route_split_rcpts(connect_route * route, GList * rcpt_list, GList ** p_rcpt_list, GList ** p_non_rcpt_list)
 {
 	GList *tmp_list = NULL;
 	/* sort out those domains that can be sent over this connection: */
-	if (route->allowed_rcpt_domains) {
-		DEBUG(5) debugf("testing for route->allowed_rcpt_domains\n");
-		rcptlist_with_one_of_hostlist(rcpt_list, route->allowed_rcpt_domains, &tmp_list, p_non_rcpt_list);
+	if (route->allowed_recipients) {
+		DEBUG(5) debugf("testing for route->allowed_recipients\n");
+		split_rcpts(rcpt_list, route->allowed_recipients, NULL, &tmp_list, p_non_rcpt_list);
 	} else {
-		DEBUG(5) debugf("route->allowed_rcpt_domains == NULL\n");
+		DEBUG(5) debugf("route->allowed_recipients == NULL\n");
 		tmp_list = g_list_copy(rcpt_list);
 	}
 
 	/* sort out those domains that cannot be sent over this connection: */
-	rcptlist_with_one_of_hostlist(tmp_list, route->not_allowed_rcpt_domains, p_non_rcpt_list, p_rcpt_list);
+	split_rcpts(tmp_list, route->denied_recipients, NULL, p_non_rcpt_list, p_rcpt_list);
 	g_list_free(tmp_list);
 }
 
