@@ -121,7 +121,6 @@ create_smtpbase(gint sock)
 
 	psb->sock = sock;
 
-	psb->use_esmtp = FALSE;
 	psb->use_size = FALSE;
 	psb->use_pipelining = FALSE;
 	psb->use_auth = FALSE;
@@ -171,6 +170,9 @@ read_response(smtp_base * psb, int timeout)
 		buf_pos += len;
 
 	} while (code[3] == '-');
+	if (psb->buffer) {
+		DEBUG(4) debugf("S: %s\n", psb->buffer);
+	}
 
 	return TRUE;
 }
@@ -182,7 +184,7 @@ check_response(smtp_base * psb, gboolean after_data)
 
 	if (((c == '2') && !after_data) || ((c == '3') && after_data)) {
 		psb->error = smtp_ok;
-		DEBUG(6) debugf("response OK:'%s' after_date = %d\n", psb->buffer, (int) after_data);
+		DEBUG(6) debugf("response OK:'%s' after_data = %d\n", psb->buffer, (int) after_data);
 		return TRUE;
 	} else {
 		if (c == '4')
@@ -191,24 +193,11 @@ check_response(smtp_base * psb, gboolean after_data)
 			psb->error = smtp_fail;
 		else
 			psb->error = smtp_syntax;
-		DEBUG(6) debugf("response failure:'%s' after_date = %d\n", psb->buffer, (int) after_data);
+		DEBUG(6) debugf("response failure:'%s' after_data = %d\n", psb->buffer, (int) after_data);
 		return FALSE;
 	}
 }
 
-static gboolean
-check_init_response(smtp_base * psb)
-{
-	if (check_response(psb, FALSE)) {
-		psb->use_esmtp = (strstr(psb->buffer, "ESMTP") != NULL);
-
-		DEBUG(4) debugf(psb->use_esmtp ? "uses esmtp\n" : "no esmtp\n");
-
-		return TRUE;
-	}
-	return FALSE;
-}
-
 static gchar*
 get_response_arg(gchar * response)
 {
@@ -294,42 +283,58 @@ check_helo_response(smtp_base * psb)
 	return TRUE;
 }
 
+/*
+We first try EHLO, but if it fails HELO in a second fall back try.
+This is what is requested by RFC 2821 (sec 3.2):
+
+	Once the server has sent the welcoming message and
+	the client has received it, the client normally sends
+	the EHLO command to the server, [...]
+	For a particular connection attempt, if the server
+	returns a "command not recognized" response to EHLO,
+	the client SHOULD be able to fall back and send HELO.
+
+Up to and including version 0.3.0 masqmail used ESMTP only if the
+string ``ESMTP'' appeared within the server's greeting message. This
+made it impossible to use AUTH with servers that would send odd
+greeting messages.
+*/
 static gboolean
 smtp_helo(smtp_base * psb, gchar * helo)
 {
-	while (TRUE) {
-		if (psb->use_esmtp) {
-			fprintf(psb->out, "EHLO %s\r\n", helo);
-			fflush(psb->out);
+	fprintf(psb->out, "EHLO %s\r\n", helo);
+	fflush(psb->out);
+	DEBUG(4) debugf("C: EHLO %s\r\n", helo);
 
-			DEBUG(4) debugf("EHLO %s\r\n", helo);
-
-		} else {
-			fprintf(psb->out, "HELO %s\r\n", helo);
-			fflush(psb->out);
-
-			DEBUG(4) debugf("HELO %s\r\n", helo);
-
-		}
-
-		if (!read_response(psb, SMTP_CMD_TIMEOUT))
-			return FALSE;
-
-		if (check_helo_response(psb))
-			return TRUE;
-		else {
-			if (psb->error == smtp_fail) {
-				if (psb->use_esmtp) {
-					/* our guess that server understands EHLO was wrong, try again with HELO */
-					psb->use_esmtp = FALSE;
-				} else {
-					/* what sort of server ist THAT ?!  give up...  */
-					return FALSE;
-				}
-			} else
-				return FALSE;
-		}
+	if (!read_response(psb, SMTP_CMD_TIMEOUT)) {
+		return FALSE;
 	}
+	if (check_helo_response(psb)) {
+		DEBUG(4) debugf("uses esmtp\n");
+		return TRUE;
+	}
+
+	if (psb->error != smtp_fail) {
+		return FALSE;
+	}
+
+	/* our guess that server understands EHLO could have been wrong,
+	   try again with HELO */
+
+	fprintf(psb->out, "HELO %s\r\n", helo);
+	fflush(psb->out);
+	DEBUG(4) debugf("C: HELO %s\r\n", helo);
+
+	if (!read_response(psb, SMTP_CMD_TIMEOUT)) {
+		return FALSE;
+	}
+	if (check_helo_response(psb)) {
+		DEBUG(4) debugf("uses smtp\n");
+		return TRUE;
+	}
+
+	/* what sort of server ist THAT ?!  give up... */
+	return FALSE;
 }
 
 static void
@@ -339,13 +344,13 @@ smtp_cmd_mailfrom(smtp_base * psb, address * return_path, guint size)
 		fprintf(psb->out, "MAIL FROM:%s SIZE=%d\r\n", addr_string(return_path), size);
 		fflush(psb->out);
 
-		DEBUG(4) debugf("MAIL FROM:%s SIZE=%d\r\n", addr_string(return_path), size);
+		DEBUG(4) debugf("C: MAIL FROM:%s SIZE=%d\r\n", addr_string(return_path), size);
 
 	} else {
 		fprintf(psb->out, "MAIL FROM:%s\r\n", addr_string(return_path));
 		fflush(psb->out);
 
-		DEBUG(4) debugf("MAIL FROM:%s\r\n", addr_string(return_path));
+		DEBUG(4) debugf("C: MAIL FROM:%s\r\n", addr_string(return_path));
 	}
 }
 
@@ -354,7 +359,7 @@ smtp_cmd_rcptto(smtp_base * psb, address * rcpt)
 {
 	fprintf(psb->out, "RCPT TO:%s\r\n", addr_string(rcpt));
 	fflush(psb->out);
-	DEBUG(4) debugf("RCPT TO:%s\n", addr_string(rcpt));
+	DEBUG(4) debugf("C: RCPT TO:%s\n", addr_string(rcpt));
 }
 
 static void
@@ -434,6 +439,7 @@ send_data(smtp_base * psb, message * msg)
 
 	fprintf(psb->out, ".\r\n");
 	fflush(psb->out);
+	DEBUG(4) debugf("C: .\n");
 }
 
 void
@@ -507,15 +513,14 @@ smtp_out_open(gchar * host, gint port, GList * resolve_list)
 }
 
 smtp_base*
-smtp_out_open_child(gchar * cmd)
+smtp_out_open_child(gchar * cmd, char* host)
 {
 	smtp_base *psb;
 	gint sock;
 
 	DEBUG(5) debugf("smtp_out_open_child entered, cmd = %s\n", cmd);
-
+	psb->remote_host = host;
 	sock = child(cmd);
-
 	if (sock > 0) {
 		psb = create_smtpbase(sock);
 		psb->remote_host = NULL;
@@ -533,7 +538,7 @@ smtp_out_rset(smtp_base * psb)
 
 	fprintf(psb->out, "RSET\r\n");
 	fflush(psb->out);
-	DEBUG(4) debugf("RSET\n");
+	DEBUG(4) debugf("C: RSET\n");
 
 	if ((ok = read_response(psb, SMTP_CMD_TIMEOUT)))
 		if (check_response(psb, FALSE))
@@ -551,7 +556,7 @@ smtp_out_auth_cram_md5(smtp_base * psb)
 {
 	gboolean ok = FALSE;
 
-	fprintf(psb->out, "AUTH CRAM-MD5\r\n");
+	fprintf(psb->out, "C: AUTH CRAM-MD5\r\n");
 	fflush(psb->out);
 	DEBUG(4) debugf("AUTH CRAM-MD5\n");
 	if ((ok = read_response(psb, SMTP_CMD_TIMEOUT))) {
@@ -591,7 +596,8 @@ smtp_out_auth_cram_md5(smtp_base * psb)
 
 			fprintf(psb->out, "%s\r\n", reply64);
 			fflush(psb->out);
-			DEBUG(4) debugf("  reply64 = %s\n", reply64);
+			DEBUG(6) debugf("  reply64 = %s\n", reply64);
+			DEBUG(6) debugf("C: %s\n", reply64);
 
 			if ((ok = read_response(psb, SMTP_CMD_TIMEOUT)))
 				ok = check_response(psb, FALSE);
@@ -611,6 +617,7 @@ smtp_out_auth_login(smtp_base * psb)
 	gboolean ok = FALSE;
 	fprintf(psb->out, "AUTH LOGIN\r\n");
 	fflush(psb->out);
+	DEBUG(4) debugf("C: AUTH LOGIN\r\n");
 	if ((ok = read_response(psb, SMTP_CMD_TIMEOUT))) {
 		if ((ok = check_response(psb, TRUE))) {
 			gchar *resp64;
@@ -620,26 +627,28 @@ smtp_out_auth_login(smtp_base * psb)
 
 			DEBUG(5) debugf("smtp_out_auth_login():\n");
 			resp64 = get_response_arg(&(psb->buffer[4]));
-			DEBUG(5) debugf("  encoded response = %s\n", resp64);
+			DEBUG(5) debugf("  encoded response = `%s'\n", resp64);
 			resp = base64_decode(resp64, &resp_size);
 			g_free(resp64);
-			DEBUG(5) debugf("  decoded response = %s, size = %d\n", resp, resp_size);
+			DEBUG(5) debugf("  decoded response = `%s', size = %d\n", resp, resp_size);
 			g_free(resp);
 			reply64 = base64_encode(psb->auth_login, strlen(psb->auth_login));
 			fprintf(psb->out, "%s\r\n", reply64);
 			fflush(psb->out);
+			DEBUG(6) debugf("C: %s\n", reply64);
 			g_free(reply64);
 			if ((ok = read_response(psb, SMTP_CMD_TIMEOUT))) {
 				if ((ok = check_response(psb, TRUE))) {
 					resp64 = get_response_arg(&(psb->buffer[4]));
-					DEBUG(5) debugf("  encoded response = %s\n", resp64);
+					DEBUG(5) debugf("  encoded response = `%s'\n", resp64);
 					resp = base64_decode(resp64, &resp_size);
 					g_free(resp64);
-					DEBUG(5) debugf("  decoded response = %s, size = %d\n", resp, resp_size);
+					DEBUG(5) debugf("  decoded response = `%s', size = %d\n", resp, resp_size);
 					g_free(resp);
 					reply64 = base64_encode(psb->auth_secret, strlen(psb->auth_secret));
 					fprintf(psb->out, "%s\r\n", reply64);
 					fflush(psb->out);
+					DEBUG(6) debugf("C: %s\n", reply64);
 					g_free(reply64);
 					if ((ok = read_response(psb, SMTP_CMD_TIMEOUT)))
 						ok = check_response(psb, FALSE);
@@ -683,13 +692,9 @@ smtp_out_init(smtp_base * psb, gboolean instant_helo)
 
 	logwrite(LOG_INFO, "smtp_out_init(): instant_helo:%d\n", instant_helo);
 
-	if (instant_helo) {
-		/* we say hello right away, hence we don't know if
-		   ESMTP is supported; we just assume it */
-		psb->use_esmtp = 1;
-	} else {
+	if (!instant_helo) {
 		if ((ok = read_response(psb, SMTP_INITIAL_TIMEOUT))) {
-			ok = check_init_response(psb);
+			ok = check_response(psb, FALSE);
 		}
 		if (!ok) {
 			smtp_out_log_failure(psb, NULL);
@@ -794,7 +799,7 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 			fprintf(psb->out, "DATA\r\n");
 			fflush(psb->out);
 
-			DEBUG(4) debugf("DATA\r\n");
+			DEBUG(4) debugf("C: DATA\r\n");
 
 			if (psb->use_pipelining) {
 				/* the first pl'ed command was MAIL FROM
@@ -877,8 +882,8 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 		for (rcpt_node = g_list_first(rcpt_list); rcpt_node; rcpt_node = g_list_next(rcpt_node)) {
 			address *rcpt = (address *) (rcpt_node->data);
 			if (addr_is_delivered(rcpt))
-				logwrite(LOG_NOTICE, "%s => %s host=%s with %s\n", msg->uid, addr_string(rcpt),
-				         psb->remote_host, psb->use_esmtp ? "esmtp" : "smtp");
+				logwrite(LOG_NOTICE, "%s => %s host=%s\n",
+				         msg->uid, addr_string(rcpt), psb->remote_host);
 		}
 	} else {
 		/* if something went wrong,
@@ -898,7 +903,7 @@ smtp_out_quit(smtp_base * psb)
 	fprintf(psb->out, "QUIT\r\n");
 	fflush(psb->out);
 
-	DEBUG(4) debugf("QUIT\n");
+	DEBUG(4) debugf("C: QUIT\n");
 
 	signal(SIGALRM, SIG_DFL);
 
