@@ -54,7 +54,6 @@ typedef struct _smtp_base {
 	gchar *buffer;
 	gint last_code;
 
-	gboolean use_esmtp;
 	gboolean use_size;
 	gboolean use_pipelining;
 	gboolean use_auth;
@@ -75,7 +74,7 @@ gchar *set_heloname(smtp_base * psb, gchar * default_name, gboolean do_correct);
 gboolean set_auth(smtp_base * psb, gchar * name, gchar * login, gchar * secret);
 void destroy_smtpbase(smtp_base * psb);
 smtp_base *smtp_out_open(gchar * host, gint port, GList * resolve_list);
-smtp_base *smtp_out_open_child(gchar * cmd);
+smtp_base *smtp_out_open_child(gchar * cmd, char* host);
 gboolean smtp_out_rset(smtp_base * psb);
 gboolean smtp_out_init(smtp_base * psb, gboolean instant_helo);
 gint smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt_list, GList * hdr_list);
