@@ -182,13 +182,16 @@ spool_read_header(message * msg)
 	/* mail headers */
 	while ((len = read_line(in, buf, MAX_DATALINE)) > 0) {
 		if (strncasecmp(buf, "HD:", 3) == 0) {
+			DEBUG(6) debugf("spool_read_header(): hdr start\n");
 			hdr = get_header(&(buf[3]));
 			msg->hdr_list = g_list_append(msg->hdr_list, hdr);
 		} else if ((buf[0] == ' ' || buf[0] == '\t') && hdr) {
+			DEBUG(6) debugf("spool_read_header(): hdr continuation\n");
 			char *tmp = hdr->header;
 			/* header continuation */
 			hdr->header = g_strconcat(hdr->header, buf, NULL);
 			hdr->value = hdr->header + (hdr->value - tmp);
+			free(tmp);  /* because g_strconcat() allocs and copies */
 		} else {
 			break;
 		}
@@ -209,11 +212,12 @@ msg_spool_read(gchar * uid, gboolean do_readdata)
 	DEBUG(4) debugf("msg_spool_read():\n");
 	/* header spool: */
 	ok = spool_read_header(msg);
-	DEBUG(4) debugf("  spool_read_header()=%d, do_readdata=%d\n", ok, do_readdata);
+	DEBUG(4) debugf("  spool_read_header() returned: %d (do_readdata had been: %d)\n",
+	                ok, do_readdata);
 	if (ok && do_readdata) {
 		/* data spool: */
 		ok = spool_read_data(msg);
-		DEBUG(4) debugf("  spool_read_data()=%d\n", ok);
+		DEBUG(4) debugf("  spool_read_data() returned: %d\n", ok);
 	}
 	return msg;
 }
