@@ -22,17 +22,15 @@
 #include "masqmail.h"
 
 gint
-time_interval(gchar * str, gint * pos)
+time_interval(gchar * str)
 {
 	gchar buf[16];
 	gchar *p = str, *q = buf;
 	gint factor = 1, val;
 
-	while (*p && isdigit(*p) && (q < buf + 15)) {
+	while (*p && isdigit(*p) && (q < buf+sizeof(buf)-1)) {
 		*(q++) = *(p++);
-		(*pos)++;
 	}
-	(*pos)++;
 	*q = '\0';
 	val = atoi(buf);
 
